==> qmmp_0.7.6.orig.tar.gz: qmmp-0.7.6/src/app/translations/qmmp_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Skip forward in playlist</source>
        <translation>Avanzar en la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Skip backwards in playlist</source>
        <translation>Retroceder en la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="64"/>
        <source>Start playing current song</source>
        <translation>Empezar reproduciendo la canción actual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="63"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>No limpiar la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="65"/>
        <source>Pause current song</source>
        <translation>Pausar la canción actual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="66"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pausar si se está reproduciendo, o viceversa</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="67"/>
        <source>Stop current song</source>
        <translation>Detener la canción actual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="68"/>
        <source>Display Jump to File dialog</source>
        <translation>Mostrar el diálogo Saltar a archivo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="69"/>
        <source>Quit application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="70"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Cambiar el volumen de reproducción (ejemplo: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Show/hide application</source>
        <translation>Mostrar/ocultar aplicación</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Display Add File dialog</source>
        <translation>Mostrar el diálogo Añadir archivo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Display Add Directory dialog</source>
        <translation>Mostrar el diálogo Añadir directorio</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="286"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Uso: qmmp [opciones] [archivos]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="287"/>
        <source>Options:</source>
        <translation>Opciones: </translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="293"/>
        <source>Print version number and exit</source>
        <translation>Mostrar el número de versión y salir</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="294"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Enviar ideas, parches, errores a: forkotov02@hotmail.ru</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="299"/>
        <source>QMMP version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="300"/>
        <source>Compiled with Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="301"/>
        <source>Using Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="292"/>
        <source>Display this text and exit</source>
        <translation>Muestra este texto y sale</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="83"/>
        <source>Unknown command</source>
        <translation>Comando desconocido</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="291"/>
        <source>Don&apos;t start the application</source>
        <translation>No iniciar la aplicación</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/app/translations/qmmp_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>Avanzar en la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>Retroceder en la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Empezar reproduciendo la canción actual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>No limpiar la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pausar la canción actual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pausar si se está reproduciendo, o viceversa</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Detener la canción actual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Mostrar el diálogo Saltar a archivo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Cambiar el volumen de reproducción (ejemplo: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>Mostrar/ocultar aplicación</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>Mostrar el diálogo Añadir archivo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>Mostrar el diálogo Añadir directorio</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="315"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Uso: qmmp [opciones] [archivos]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="316"/>
        <source>Options:</source>
        <translation>Opciones: </translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="322"/>
        <source>Print version number and exit</source>
        <translation>Mostrar el número de versión y salir</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="323"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Enviar ideas, parches, errores a: forkotov02@hotmail.ru</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="326"/>
        <source>Command Line Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="339"/>
        <source>QMMP version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="340"/>
        <source>Compiled with Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="341"/>
        <source>Using Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="344"/>
        <source>Qmmp Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="321"/>
        <source>Display this text and exit</source>
        <translation>Muestra este texto y sale</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="88"/>
        <source>Unknown command</source>
        <translation>Comando desconocido</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="320"/>
        <source>Don&apos;t start the application</source>
        <translation>No iniciar la aplicación</translation>
    </message>
</context>
</TS>
